@@ -12,12 +12,15 @@
 
 #pragma once
 
+#include <QList>
 #include <QObject>
+#include <QSharedPointer>
 #include <QString>
-#include <QVector>
 
 namespace KScreen
 {
+class Config;
+
 struct OsdAction {
     Q_GADGET
     Q_PROPERTY(QString label MEMBER label CONSTANT)
@@ -38,7 +41,8 @@ public:
     QString label;
     QString iconName;
 
-    static QVector<OsdAction> availableActions();
+    static QList<OsdAction> availableActions();
+    static void applyAction(const QSharedPointer<KScreen::Config> &config, Action action);
 };
 
 } // namespace KScreen
